/*
 *	Copyright (C) 2007, 2008, 2009. PARP Research Group.
 *	<http://perception.inf.um.es>
 *	University of Murcia, Spain.
 *
 *	This file is part of the QVision library.
 *
 *	QVision is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as
 *	published by the Free Software Foundation, version 3 of the License.
 *
 *	QVision is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with QVision. If not, see <http://www.gnu.org/licenses/>.
 */

/// @file
/// @brief File from the QVision library.
/// @author PARP Research Group. University of Murcia, Spain.

#include <limits>
#include <iostream>

#include <qvmath.h>
#include <qvdefines.h>
#include <qvmatrixalgebra.h>

#include <QString>
#include <QVMatrix>


//////////////////////////
// Constructors

QVMatrix::QVMatrix():
	cols(1), rows(1), data(new QBlasDataBuffer(cols*rows))
	{
	operator()(0,0) = 1;
	}

QVMatrix::QVMatrix(const QVMatrix &matrix):
	cols(matrix.cols), rows(matrix.rows), data(matrix.data)
	{ }

QVMatrix::QVMatrix(const int rows, const int cols, const double *data):
	cols(cols), rows(rows), data(new QBlasDataBuffer(cols*rows))
	{
	if (data != NULL)
		for (int r = 0; r < rows; r++)
			for (int c = 0; c < cols; c++)
				operator()(r, c) = data[r*cols + c];
	}

QVMatrix::QVMatrix(const int rows, const int cols, const double value):
	cols(cols), rows(rows), data(new QBlasDataBuffer(cols*rows))
	{
	set(value);
	}

QVMatrix::QVMatrix(const QVQuaternion &quaternion): cols(4), rows(4), data(new QBlasDataBuffer(cols*rows))
	{
	*this = QVMatrix::identity(4);

	const double	norm = quaternion.norm2(),
			w = quaternion[0] / norm,
			x = quaternion[1] / norm,
			y = quaternion[2] / norm,
			z = quaternion[3] / norm;

	operator()(0,0) = 1 - 2.0 * (x * x + y * y);
	operator()(0,1) = + 2.0 * (w * x - y * z);
	operator()(0,2) = + 2.0 * (y * w + x * z);
	
	operator()(1,0) = + 2.0 * (w * x + y * z);
	operator()(1,1) = 1 - 2.0 * (y * y + w * w);
	operator()(1,2) = + 2.0 * (x * y - w * z);
	
	operator()(2,0) = + 2.0 * (y * w - x * z);
	operator()(2,1) = + 2.0 * (x * y + w * z);
	operator()(2,2) = 1 - 2.0 * (x * x + w * w);

/*
	operator()(0,0) += - 2.0 * (quaternion[1] * quaternion[1] + quaternion[2] * quaternion[2]);
	operator()(0,1) += + 2.0 * (quaternion[0] * quaternion[1] - quaternion[2] * quaternion[3]);
	operator()(0,2) += + 2.0 * (quaternion[2] * quaternion[0] + quaternion[1] * quaternion[3]);
	
	operator()(1,0) += + 2.0 * (quaternion[0] * quaternion[1] + quaternion[2] * quaternion[3]);
	operator()(1,1) += - 2.0 * (quaternion[2] * quaternion[2] + quaternion[0] * quaternion[0]);
	operator()(1,2) += + 2.0 * (quaternion[1] * quaternion[2] - quaternion[0] * quaternion[3]);
	
	operator()(2,0) += + 2.0 * (quaternion[2] * quaternion[0] - quaternion[1] * quaternion[3]);
	operator()(2,1) += + 2.0 * (quaternion[1] * quaternion[2] + quaternion[0] * quaternion[3]);
	operator()(2,2) += - 2.0 * (quaternion[1] * quaternion[1] + quaternion[0] * quaternion[0]);*/
	}

QVMatrix::QVMatrix(const QVVector &vector, const bool rowVector):
	cols(rowVector?vector.size():1), rows(rowVector?1:vector.size()), data(new QBlasDataBuffer(cols*rows))
	{
	if (rowVector)
		setRow(0, vector);
	else
		setCol(0, vector);
	}

QVMatrix::QVMatrix(const QList<QVVector> &vectorList): cols(vectorList.at(0).size()), rows(vectorList.size()), data(new QBlasDataBuffer(cols*rows))
	{
	for (int n = 0; n < getRows(); n++)
		{
		Q_ASSERT(vectorList.at(n).size() == getCols());
		setRow(n, vectorList.at(n));
		}
	}

QVMatrix::QVMatrix(const QList< QVector<double> > &vectorList): cols(vectorList.at(0).size()), rows(vectorList.size()), data(new QBlasDataBuffer(cols*rows))
	{
	for (int n = 0; n < getRows(); n++)
		{
		Q_ASSERT(vectorList.at(n).size() == getCols());
		setRow(n, vectorList.at(n));
		}
	}

QVMatrix::QVMatrix(const gsl_matrix *matrix): cols(matrix->size2), rows(matrix->size1), data(new QBlasDataBuffer(cols*rows))
	{
	for(int i = 0; i < rows; i++)
		for(int j = 0; j < cols; j++)
			operator()(i, j) = gsl_matrix_get(matrix, i, j);
	}

QVMatrix::QVMatrix(const QList<QPointF> &pointList): cols(2), rows(pointList.size()), data(new QBlasDataBuffer(cols*rows))
	{
	for (int n = 0; n < getRows(); n++)
		setRow(n, pointList.at(n));
	}

#ifdef OPENCV
QVMatrix::QVMatrix(const CvMat *cvMatrix): cols(cvMatrix->cols), rows(cvMatrix->rows), data(new QBlasDataBuffer(cols*rows))
	{
	for (int i = 0; i < rows; i++)
			for (int j = 0; j < cols; j++)
				this->operator()(i,j) = cvmGet(cvMatrix, i, j);
	}

CvMat *QVMatrix::toCvMat(const int cvMatType) const
	{
	Q_ASSERT( (cvMatType == CV_32F) || (cvMatType == CV_64F) );

	CvMat *result = cvCreateMat(rows, cols, cvMatType);

	for (int i = 0; i < rows; i++)
			for (int j = 0; j < cols; j++)
				cvmSet(result, i, j, this->operator()(i,j));
	return result;
	}

#endif

/////////////////////////
QVMatrix & QVMatrix::operator=(const QVMatrix &matrix)
	{
	cols = matrix.cols;
	rows = matrix.rows;
	data = matrix.data;

	return *this;
	}

/////////////////////////

QVVector QVMatrix::operator*(const QVVector &vector) const
	{
	Q_ASSERT(vector.size() == getCols());
	return dotProduct(vector.toColumnMatrix()).getCol(0);
	}

/////////////////////////

bool QVMatrix::equals(const QVMatrix &matrix) const
	{
	// Check valences for both matrixs are equivalent
	if (cols != matrix.cols || rows != matrix.rows)
		return false;

	// Check data in both matrixs is equal
	const double	*data1 = getReadData(),
			*data2 = matrix.getReadData();

	for (int i = 0; i < getDataSize(); i++)
		if (data1[i] != data2[i])
			return false;

	return true;
	}

QVMatrix QVMatrix::dotProduct(const QVMatrix &matrix) const
	{
	const int	cols1 = cols,
			rows1 = rows,
			cols2 = matrix.cols,
			rows2 = matrix.rows;

	Q_ASSERT(cols1 == rows2);

	if (cols1 != rows2)
		{
		std::cout << "ERROR: tried to multiply matrices with incompatible sizes at QVMatrix::dotProduct(const QVMatrix &matrix)." << std::endl
			<< "\tMatrix 1 dimentions:\t" << rows1 << "x" << cols1 << std::endl
			<< "\tMatrix 2 dimentions:\t" << rows2 << "x" << cols2 << std::endl;
		exit(1);
		}

	QVMatrix result(rows1, cols2);

	const int k = cols1, m = rows1, n = cols2;
 
	cblas_dgemm(CblasRowMajor, CblasNoTrans, CblasNoTrans,
			m, n, k, 1.0,
			getReadData(), k,
			matrix.getReadData(), n, 0.0,
			result.getWriteData(), n);

	return result;
	}

QVMatrix QVMatrix::elementProduct(const QVMatrix &matrix) const
	{
	const int cols1 = cols, rows1 = rows, cols2 = matrix.cols, rows2 = matrix.rows;

	Q_ASSERT(rows1 == rows2);
	Q_ASSERT(cols1 == cols2);

	if (cols1 != cols2 || rows1 != rows2)
		{
		std::cout << "ERROR: tried to multiply matrices with incompatible sizes at QVMatrix::dotProduct(const QVMatrix &matrix)." << std::endl
			<< "\tMatrix 1 dimentions:\t" << rows1 << "x" << cols1 << std::endl
			<< "\tMatrix 2 dimentions:\t" << rows2 << "x" << cols2 << std::endl;
		exit(1);
		}

	QVMatrix result(rows1, cols2);

	/// @todo use Blas
	for (int i = 0; i < cols1; i++)
		for (int j = 0; j < cols1; j++)
			result(i,j) = this->operator()(i,j) * matrix(i,j);

	return result;
	}

QVMatrix QVMatrix::matrixDivide(const QVMatrix &matrix) const
	{
	Q_ASSERT(matrix.getCols() >= matrix.getRows());
	Q_ASSERT(matrix.getCols() == (*this).getCols());

	QVMatrix result(matrix.getRows(), (*this).getRows());

	if (matrix.getCols() == matrix.getRows())
		solveLinear(matrix.transpose(), result, (*this).transpose());
	else
		solveOverDetermined(matrix.transpose(), result, (*this).transpose());

	return result.transpose();
	}

QVMatrix QVMatrix::inverse() const
	{
	/// @TODO Por ahora con la misma pseudoinversa, sería mejor de otro modo...
	return pseudoInverse(*this);
	}

double QVMatrix::det() const
	{
	return determinant(*this);
	}

QVMatrix QVMatrix::transpose() const
	{
	const int rows = getRows(), cols = getCols();

	QVMatrix result(cols, rows);

	const double 	*matrixData = getReadData();
	double		*resultData = result.getWriteData();

	/// @todo use blas function cblas_axpy for this
	for (int i = 0; i < rows; i++)
		for (int j = 0; j < cols; j++)
			resultData[j*rows+i] = matrixData[i*cols+j];

	return result;
	}

void QVMatrix::set(const double value)
	{
	double		*resultData = getWriteData();
	const int	dataSize = getDataSize();

	/// @todo use blas function cblas_axpy for data add
	for (int i = 0; i < dataSize; i++)
		resultData[i] = value;
	}

QVMatrix QVMatrix::addition(const QVMatrix &matrix) const
	{
	Q_ASSERT(cols == matrix.cols || rows == matrix.rows);

	QVMatrix result = *this;

	const double 	*matrixData = matrix.getReadData();
	double		*resultData = result.getWriteData();
	const int	dataSize = matrix.getDataSize();

	/// @todo use blas function cblas_axpy for data add

	for (int i = 0; i < dataSize; i++)
		resultData[i] += matrixData[i];

	return result;
	}

QVMatrix QVMatrix::substract(const QVMatrix &matrix) const
	{
	// Check valences for both matrixs are equivalent
	Q_ASSERT(cols == matrix.cols || rows == matrix.rows);

	QVMatrix result = *this;

	const double 	*matrixData = matrix.getReadData();
	double		*resultData = result.getWriteData();
	const int	dataSize = matrix.getDataSize();

	/// @todo use blas function cblas_axpy for data add

	for (int i = 0; i < dataSize; i++)
		resultData[i] -= matrixData[i];

	return result;
	}

QVMatrix QVMatrix::scalarProduct(const double value) const
	{
	QVMatrix result = *this;

	double		*resultData = result.getWriteData();
	const int	dataSize = getDataSize();

	/// @todo use blas function?

	for (int i = 0; i < dataSize; i++)
		resultData[i] *= value;

	return result;
	}

QVMatrix QVMatrix::scalarDivide(const double value) const
	{
	QVMatrix result = *this;

	double		*resultData = result.getWriteData();
	const int	dataSize = getDataSize();

	/// @todo use blas function?

	for (int i = 0; i < dataSize; i++)
		resultData[i] /= value;

	return result;
	}

QVMatrix QVMatrix::horizontalAppend(const QVMatrix &matrix) const
	{
	const int cols1 = cols, rows1 = rows, cols2 = matrix.cols, rows2 = matrix.rows;

	Q_ASSERT(rows1 == rows2);

	if (rows1 != rows2)
		{
		std::cout << "ERROR: tried to append horizontally matrices with different row number at QVMatrix::horizontalAppend(const QVMatrix &matrix)."
			<< std::endl
			<< "\tMatrix 1 dimentions:\t" << rows1 << "x" << cols1 << std::endl
			<< "\tMatrix 2 dimentions:\t" << rows2 << "x" << cols2 << std::endl;
		exit(1);
		}

	QVMatrix result(rows1, cols1 + cols2);

	for (int i = 0; i < cols1; i++)
		result.setCol(i, getCol(i));

	for (int i = 0; i < cols2; i++)
		result.setCol(cols1 + i, matrix.getCol(i));

	return result;
	}

QVMatrix QVMatrix::verticalAppend(const QVMatrix &matrix) const
	{
	const int cols1 = cols, rows1 = rows, cols2 = matrix.cols, rows2 = matrix.rows;

	Q_ASSERT(cols1 == cols2);

	if (cols1 != cols2)
		{
		std::cout << "ERROR: tried to append vertically matrices with different row number at QVMatrix::horizontalAppend(const QVMatrix &matrix)."
			<< std::endl
			<< "\tMatrix 1 dimentions:\t" << rows1 << "x" << cols1 << std::endl
			<< "\tMatrix 2 dimentions:\t" << rows2 << "x" << cols2 << std::endl;
		exit(1);
		}

	QVMatrix result(rows1 + rows2, cols2);

	for (int i = 0; i < rows1; i++)
		result.setRow(i, getRow(i));

	for (int i = 0; i < rows2; i++)
		result.setRow(rows1 + i, matrix.getRow(i));

	return result;
	}

/////////////////////////////////////////////////////////

double QVMatrix::norm2() const
	{ return cblas_dnrm2(getDataSize(), getReadData(), 1); };


QVMatrix QVMatrix::rowHomogeneousNormalize() const
	{
	const int cols = getCols(), rows = getRows();
	QVMatrix result(rows, cols);

	for (int i = 0; i < rows; i++)
		for (int j = 0; j < cols; j++)
			result(i,j) = operator()(i,j) / operator()(i,cols-1);
	return result;
	}

const QVVector QVMatrix::getRow(const int row) const
	{
	Q_ASSERT(row < getRows());

	const int cols = getCols();
	QVVector result(cols);
	for (int col= 0; col < cols; col++)
		result[col] = operator()(row,col);

	return result;
	}

void QVMatrix::setRow(const int row, QVVector vector)
	{
	Q_ASSERT(row < getRows());
	Q_ASSERT(getCols() == vector.size());

	const int cols = getCols();
	for (int col= 0; col < cols; col++)
		operator()(row,col) = vector[col];
	}

void QVMatrix::setRow(const int row, QVector<double> vector)
	{
	Q_ASSERT(row < getRows());
	Q_ASSERT(getCols() == vector.size());

	const int cols = getCols();
	for (int col= 0; col < cols; col++)
		operator()(row,col) = vector[col];
	}

const QVVector QVMatrix::getCol(const int col) const
	{
	Q_ASSERT(col < getCols());

	const int rows = getRows();
	QVVector result(rows);
	for (int row= 0; row < rows; row++)
		result[row] = operator()(row,col);

	return result;
	}

void QVMatrix::setCol(const int col, QVVector vector)
	{
	Q_ASSERT(col < getCols());
	Q_ASSERT(getRows() == vector.size());

	const int rows = getRows();
	for (int row= 0; row < rows; row++)
		operator()(row,col) = vector[row];
	}

const QVMatrix QVMatrix::getSubmatrix(const int firstRow, const int lastRow, const int firstCol, const int lastCol) const
	{

	Q_ASSERT(firstRow >= 0);
	Q_ASSERT(firstCol >= 0);
	Q_ASSERT(firstRow <= lastRow);
	Q_ASSERT(firstCol <= lastCol);
	Q_ASSERT(lastRow < getRows());
	Q_ASSERT(lastCol < getCols());

	QVMatrix result(lastRow - firstRow +1, lastCol - firstCol +1);

	for (int row = firstRow; row <= lastRow; row++)
		for (int col = firstCol; col < lastCol; col++)
			result(row - firstRow, col - firstCol) = operator()(row,col);

	return result;
	}
	
///////////////////////////////////////////////////
// Misc matrices

QVMatrix QVMatrix::identity(const int size)
	{
	QVMatrix result(size, size);
	result.set(0);
	for (int i= 0; i < size; i++)
		result(i,i) = 1;
	return result;
	}

QVMatrix QVMatrix::zeros(const int rows, const int cols)
	{
	QVMatrix result(rows, cols);
	result.set(0);
	return result;
	}

QVMatrix QVMatrix::random(const int rows, const int cols)
	{
	QVMatrix result(rows, cols);
	for (int col = 0; col < cols; col++)
		for (int row = 0; row < rows; row++)
			result(row,col) = (double)ABS(rand()) / (double)std::numeric_limits<int>::max();
	return result;
	}

QVMatrix QVMatrix::diagonal(const QVVector &diagonalVector)
	{
	const int size = diagonalVector.size();
	QVMatrix result(size, size);
	result.set(0);
	for (int i= 0; i < size; i++)
		result(i,i) = diagonalVector[i];
	return result;
	}

QVMatrix QVMatrix::rotationMatrix(const double delta)
	{
	// Rotation[delta_] := {{Cos[delta], Sin[delta], 0}, {-Sin[delta], Cos[delta], 0}, {0, 0, 1}};
	QVMatrix result = QVMatrix::identity(3);

	result(0,0) = cos(delta);	result(0,1) = sin(delta);
	result(1,0) = -sin(delta);	result(1,1) = cos(delta);

	return result;
	}

QVMatrix QVMatrix::traslationMatrix(const double x, const double y)
	// Translation[x_, y_] := {{1, 0, x}, {0, 1, y}, {0, 0, 1}};
	{
	QVMatrix result = QVMatrix::identity(3);

	result(0,2) = x;
	result(1,2) = y;

	return result;
	}

QVMatrix QVMatrix::scaleMatrix(const double zoom)
	{
	QVMatrix result = QVMatrix::identity(3);

	result(0,0) = zoom;
	result(1,1) = zoom;

	return result;
	}

QVMatrix QVMatrix::rotationMatrix3dZAxis(const double angle)
	{
	QVMatrix result = identity(4);

	result(0,0) = cos(angle);
	result(0,1) = sin(angle);

	result(1,0) = -sin(angle);
	result(1,1) = cos(angle);

	return result;
	}

QVMatrix QVMatrix::rotationMatrix3dXAxis(const double angle)
	{
	QVMatrix result = identity(4);

	result(1,1) = cos(angle);
	result(1,2) = sin(angle);

	result(2,1) = -sin(angle);
	result(2,2) = cos(angle);

	return result;
	}

QVMatrix QVMatrix::rotationMatrix3dYAxis(const double angle)
	{
	QVMatrix result = identity(4);

	result(0,0) = cos(angle);
	result(0,2) = -sin(angle);

	result(2,0) = sin(angle);
	result(2,2) = cos(angle);

	return result;
	}

QVMatrix QVMatrix::traslationMatrix3d(const double x, const double y, const double z)
	{
	QVMatrix result = identity(4);

	result(0,3) = x;
	result(1,3) = y;
	result(2,3) = z;

	return result;
	}

QVVector QVMatrix::meanCol() const
	{
	QVVector result = getCol(0);
	for (int i = 1; i < getCols(); i++)
		result += getCol(i);
	return result / getCols();
	}

////////////////////////////////////////////////////

std::ostream& operator << ( std::ostream &os, const QVMatrix &matrix )
	{
	const int cols = matrix.getCols(), rows = matrix.getRows();

	os << "QVMatrix (" << rows << ", " << cols << ")" << std::endl;

	const double *data = matrix.getReadData();
	os << "[" << std::endl;
	for (int i=0; i < rows; i++)
		{
		os << "    [ ";
		for (int j = 0; j < cols; j++)
			os << qPrintable(QString("%1").arg(data[i*cols + j], -8, 'f', 6)) << " ";
		os << "]" << std::endl;
		}
	os << "]" << std::endl;
	return os;
	}

std::istream& operator >> ( std::istream &is, QVMatrix &matrix )
	{
	int cols, rows;
	double value;

	is.ignore(256, '(');
	is >> rows;
	is.ignore(256, ',');
	is >> cols;
	is.ignore(256, '[');
	QVMatrix maux(rows, cols);

	for (int i = 0; i < rows; i++)
		{
		is.ignore(256, '[');
		for (int j = 0; j < cols; j++)
			{
			is >> value;
			maux(i, j) = value;
			}
		}

	matrix = maux;

	return is;
	}

uint qHash(const QVMatrix &matrix)
	{
	const int cols = matrix.getCols(), rows = matrix.getRows();

	double accum = 0;
	for (int i = 0; i < cols; i++)
		for (int j = 0; j < rows; j++)
			accum += matrix(i,j) / matrix(cols-i-1, rows-j-1);

	return (uint) ((100000 * accum) / ((double) (cols + rows)));
	}


