/*
 *	Copyright (C) 2007, 2008, 2009. PARP Research Group.
 *	<http://perception.inf.um.es>
 *	University of Murcia, Spain.
 *
 *	This file is part of the QVision library.
 *
 *	QVision is free software: you can redistribute it and/or modify
 *	it under the terms of the GNU Lesser General Public License as
 *	published by the Free Software Foundation, version 3 of the License.
 *
 *	QVision is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU Lesser General Public License for more details.
 *
 *	You should have received a copy of the GNU Lesser General Public
 *	License along with QVision. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef PROJECTIVE_H
#define PROJECTIVE_H

//#include <QPair>
#include <qvmath.h>
#include <QVMatrix>

/// @file
/// @brief File from the QVision library.
/// @author PARP Research Group. University of Murcia, Spain.

//////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////// HOMOGRAPHY CALIBRATION FUNCTION ///////////////////////////////////////////////

void homogenizePoints(const QList< QPointFMatching > &matchings,
	QVMatrix &premult, QVMatrix &postmult,
	QList< QPair<QPointF, QPointF> > &homogeneizedPairs);

/*
@brief Obtains an homography from two lists of corresponding points.
@ingroup qvprojectivegeometry

This function returns the homography that maps the points from a source position to a
destination position, according to a projective transormation.

@deprecated Use @ref ComputeProjectiveHomography instead
@param sourcePoints list of source points.
@param destinationPoints list of destination points.
*/
//QVMatrix ComputeHomography(const QList<QPointF> &sourcePoints, const QList<QPointF> &destPoints);

/*!
@brief Obtains a planar homography from two lists of corresponding points.
@ingroup qvprojectivegeometry

This function obtains the planar homography which maps the location of the points from a source plane to a destination plane. One of the planes can be the image plane as well.

The function returns the matrix corresponding to the planar homography, from a list of four or more point correspondences between the location of those points at the source plane and their location in the destination plane.

This function can be used to compute a rectification homography, which can be used to obtain a frontal view of any planar figure appearing in an image. The following code and images shows this effect:

@image html rectification_homography.png

Image on the left is the original picture obtained with a pin-hole camera. Image on the right was obtained aplying a rectification homography to the pixels in the original image. This rectification homography is obtained using the function @ref ComputeProjectiveHomography with the four point correspondences between the points in the images featured with yellow dots:

@code
QList< QPair<QPointF, QPointF> > matchings;
matchings.append(QPair<QPointF, QPointF>(QPointF(-171,109),	QPointF(-100,+100)));
matchings.append(QPair<QPointF, QPointF>(QPointF(-120,31),	QPointF(-100,-100)));
matchings.append(QPair<QPointF, QPointF>(QPointF(117,53),	QPointF(+100,-100)));
matchings.append(QPair<QPointF, QPointF>(QPointF(11,115),	QPointF(+100,+100)));

const QVMatrix H = ComputeProjectiveHomography(matchings);
@endcode

The obtained matrix $H$ holds the following equation:

\f$ H \propto \left(
\begin{array}{ccc}
	0.63868		& 0.77290	& -39.73059	\\
	-0.11082	& 1.94177	& -165.90578	\\
	-0.00034	& -0.00378	& 1		\\
\end{array} \right)\f$

Also for each point matching \f$ p \mapsto p' \f$ contained in the <i>matchings</i> list, the following equation holds.

\f$ p' \propto H p \f$

or

\f$ p' \times H p = 0 \f$

In C++ source code:
@code
QPair<QPointF, QPointF> matching;
foreach(matching, matchings)
	{
	const QVVector	p_0 = QVVector::homogeneousCoordinates(matching.first),
			p_1 = QVVector::homogeneousCoordinates(matching.second);
	std::cout << "p1 x H p0 =" << (p_1 ^ H*p_0) << std::endl;
	}
@endcode

The printed values must be close to 0.

The location \f$ p_1 \f$ at the rectified version of an image corresponding to pixel \f$ p_0 \f$ at the original version of the image can be obtained given the rectification homography \f$ H \f$ using the following C++ code:

@code
QPointF p_1 = H * QVVector::homogeneousCoordinates(p_0);
@endcode

Or the @ref ApplyHomography functions.

@see ApplyHomography(const QVMatrix &, const QPointF &)
@see ApplyHomography(const QVMatrix &, const QList<QPointF> &)

@param matchings list of point matchings from the original location, to the destination location.
*/
QVMatrix ComputeProjectiveHomography(const QList< QPointFMatching > &matchings);

/*
@brief Obtains the fundamental matrix between two images, using the 8 point algorithm.
@ingroup qvprojectivegeometry
This function performs point normalization to robustly obtain the F matrix.

@param matchings list of 8 point matchings
*/
//QVMatrix ComputeFundamentalMatrix(const QList< QPointFMatching > &matchings);

/*!
@brief Obtains the fundamental matrix between two images, using the 8 point algorithm.
@ingroup qvprojectivegeometry
This function performs point normalization to robustly obtain the F matrix.

@note This function uses OpenCV functionallity. The QVision must be compiled with the OpenCV compatibility enabled to provide this function.
@param matchings list of 8 point matchings
*/
#ifdef OPENCV
QVMatrix cvFindFundamentalMat(const QList< QPointFMatching > &matchings);
#endif

/*!
@ingroup qvprojectivegeometry

This function obtains an euclidean mapping between the source an destination locations of a set of point matchings. The mapping is returned as a \f$ 3 \times 3 \f$ matrix which can be multiplied to the source location of each mapping point in homogeneous coordinates, obtaining a location close to the destination location from the matching.

@todo write documentation for this function
*/
QVMatrix ComputeEuclideanHomography(const QList< QPointFMatching > &matchings);

/*!
@brief Obtains the homogenized coordinates of a point mapped using an homography transformation.
@ingroup qvprojectivegeometry

This function obtains the point \f$ (x', y') \f$ which holds the following equation:

\f$ \left(\begin{array}{c} x' \\ y' \\ 1 \end{array}\right) \propto H \left(\begin{array}{c} x \\ y \\ 1 \end{array}\right) \f$

Where \f$ H \f$ and \f$ (x,y) \f$ are the input transformation homography and point respectively. Matrix \f$ H \f$ must be of size \f$ 3 \times 3 \f$.

@see ComputeProjectiveHomography
@param homography The homography transformation matrix
@param point Point to apply the homography transformation
*/
QPointF ApplyHomography(const QVMatrix &homography, const QPointF &point);

/*!
@brief Obtains the homogenized coordinates of a set of points mapped using an homography transformation.
@ingroup qvprojectivegeometry

This function applies a transformation homography over a set of points. For further info about this mapping see function @ref ApplyHomography(const QVMatrix &, const QPointF &).

@see ApplyHomography(const QVMatrix &, const QPointF &)
@see ComputeProjectiveHomography

@param homography The homography transformation matrix
@param sourcePoints Points to apply the homography transformation
*/
QList<QPointF> ApplyHomography(const QVMatrix &homography, const QList<QPointF> &sourcePoints);

/*!
@brief Function to test if a 3x3 matrix corresponds to an homography.
@ingroup qvprojectivegeometry

Every matrix which holds a perspective deformation from one plane to another should validate some constrains. The most important is that its two first columns
should be perpendicular, and with a similar size, because for the matrix to correspond to an homography, they should be contained in a base of a rotated coordinate system.
Given the following homography matrix:

\f$ H = \left[ R_1 R_2 -CR^t \right] \f$

The error value returned by this function for it will be:

\f$ error = \left| \frac{ \|R_1\| - \|R_2\| }{ \|R_1\| + \|R_2\| } \right| + \left| \frac{ R_1 \cdot R_2}{ \|R_1\| \|R_2\| } \right| \f$

That error is a measure of the difference of sizes between the norm of the two column vectors of the homography, corresponding to the two first columns of the rotation matrix, and their dot product. When both values are close to zero, the matrix corresponds to an homography, and it won't otherwise.

A good method to prove that a matrix corresponds to an homography using this function, can be done testing the return value with a threshold of aproximately 0.3. If the return value of this function for a matrix is lower than this threshold, that matrix is likely to correspond to an homography, and is not likely to correspond otherwise.

@param homography a possible homography matrix.
@return a value close to 1 when the matrix doesn't corresponds to an homography, and close to 0 when it is close to be an homography.
*/
double HomographyTestError(const QVMatrix &homography);

/*!
@ingroup qvprojectivegeometry

@todo write documentation for this function
*/
void GetExtrinsicCameraMatrixFromHomography(const QVMatrix &K, const QVMatrix &H, QVMatrix &M4x4);

/*!
@brief Diagonal intrinsic camera matrix calibration
@ingroup qvprojectivegeometry

This function obtains a diagonal intrinsic camera matrix, consisting on the focal distance only. This matrix is such that

\f$ H = K \left[ R | t\right]	\f$

Where \f$ R \f$ is a rotation matrix. This function returns a direct approximation for the \f$ K \f$ matrix.

@todo rename to GetDirectCameraIntrinsicsFromPlanarHomography
@see GetIntrinsicCameraMatrixFromHomography
*/
void GetDirectIntrinsicCameraMatrixFromHomography(const QVMatrix &H, QVMatrix &K);

/*!
@brief Diagonal intrinsic camera matrix calibration
@ingroup qvprojectivegeometry

This function obtains a diagonal intrinsic camera matrix, consisting on the focal distance only. This matrix is such that

\f$ H = K \left[ R | t\right]	\f$

Where \f$ R \f$ is a rotation matrix. This matrix is obtained with a minimization process, so its result is more precise than that obtained with @ref GetDirectIntrinsicCameraMatrixFromHomography function.

@see GetDirectIntrinsicCameraMatrixFromHomography
*/
//void GetIntrinsicCameraMatrixFromHomography(const QVMatrix &H, QVMatrix &K,
//	double focal = 3, const double maxFocal = 50, const int maxIterations = 100, const double maxError = 0.00001);

/*!
@ingroup qvprojectivegeometry
@todo write documentation for this function
*/
void CalibrateCameraFromPlanarHomography(const QVMatrix &H, QVMatrix &K, QVMatrix &Rt);

/*!
@brief Obtains the intrinsic camera matrix from a planar homography
@ingroup qvprojectivegeometry

This functions obtains the intrinsic calibration matrix \f$ K \f$ corresponding to a simple pinhole camera model. The intrinsic camera matrix has only one free parameter, related to the focal distance of the camera:

\f$
K = \begin{array}{ccc}
f	& 0	& 0	\\
0	& f	& 0	\\
0	& 0	& 1	\\
\end{array}
\f$

This function should receive a planar homography corresponding to the mapping of a set of know template points, to an image frame captured with the camera containing a view of that template.

The following is an example of a full intrinsic camera calibration, knowing a set of point matchings between the template image and the input image read from the camera:

@code
[...]
QList< QPointFMatching > matchings;
matchings.append(QPointFMatching(QPointF(-171,109),	QPointF(-100,+100)));
matchings.append(QPointFMatching(QPointF(-120,31),	QPointF(-100,-100)));
matchings.append(QPointFMatching(QPointF(117,53),	QPointF(+100,-100)));
matchings.append(QPointFMatching(QPointF(11,115),	QPointF(+100,+100)));

QVMatrix H, K;
H = ComputeProjectiveHomography(matchings);
GetPinholeCameraIntrinsicsFromPlanarHomography(H, K);
[...]
@endcode

For further understanding of the planar homography calibration process, see @ref ComputeProjectiveHomography function documentation.

@param H			Input planar homography.
@param K			Matrix to store the intrinsic camera matrix
@param iterations		Cumber of iterations to perform camera calibration
@param maxGradientNorm		Minimal value of the gradient size (norm 2) to stop the minimization when reached.
@param step			Corresponds to parameter <i>step</i> for the <i>gsl_multimin_fdfminimizer_set</i> function.
@param tol			Corresponds to parameter <i>tol</i> for the <i>gsl_multimin_fdfminimizer_set</i> function.

@return a value close to 1 when the matrix doesn't corresponds to an homography, and close to 0 when it is close to be an homography.
@see ComputeProjectiveHomography
*/
void GetPinholeCameraIntrinsicsFromPlanarHomography(	const QVMatrix &H, QVMatrix &K, const int iterations = 100,
						const double maxGradientNorm = 1e-3, const double step = 0.01, const double tol = 1e-4);
#endif
